\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{mitletter3}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{letter}}
\ProcessOptions
\LoadClass{letter}
\usepackage{graphicx}
\usepackage[businessenvelope]{envlab}

\usepackage{color}
\usepackage[usenames,dvipsnames,svgnames,table]{xcolor}
\definecolor{mitred}{RGB}{128,0,0}

\raggedright

\setlength{\topmargin}{-.80in}
\setlength{\oddsidemargin}{-.25in}
\setlength{\evensidemargin}{-.25in}
\setlength{\textwidth}{7in}
\setlength{\textheight}{8.3in}
\setlength{\headsep}{1in}
\setlength{\footskip}{0.45in}

\DeclareFixedFont{\boldfont}{OT1}{cmss}{bx}{n}{8}
\DeclareFixedFont{\regularfont}{OT1}{cmss}{m}{n}{8}
 \DeclareFixedFont{\italicfont}{OT1}{cmr}{m}{it}{10}

\renewcommand*{\opening}[1]{\ifx\@empty\fromaddress
  \thispagestyle{firstpage}%
    {\raggedleft\@date\par}%
  \else  % home address
    \thispagestyle{empty}%
    {\raggedleft\begin{tabular}{l@{}}\ignorespaces
      \fromaddress \\*[2\parskip]%
      \@date \end{tabular}\par}%
  \fi
  \vspace{2\parskip}%
  {\raggedright \toname \\ \toaddress \par}%
  \vspace{2\parskip}%
  #1\par\nobreak}
\renewcommand{\ps@headings}{% 
  \renewcommand{\@evenfoot}{\usebox{\footer}}
  \renewcommand{\@oddfoot}{\usebox{\footer}}
      \def\@oddhead{\slshape\headtoname{} \ignorespaces\toname
                    \hfil \pagename{} \thepage}%
      \let\@evenhead\@oddhead}
\renewcommand*{\opening}[1]{\ifx\@empty\fromaddress
  \thispagestyle{firstpage}%
    \@date\\%
  \else  % home address
    \thispagestyle{empty}%
    {\raggedleft\begin{tabular}{l@{}}\ignorespaces
      \fromaddress \\*[2\parskip]%
      \@date \end{tabular}\par}%
  \fi
  \vspace{2\parskip}%
  {\raggedright \toname \\ \toaddress \par}%
  \vspace{2\parskip}%
  #1\par\nobreak}
\renewcommand*{\signature}[1]{\def\fromsig{#1}}
\newcommand{\officename}{MIT Sloan School of Management\\MIT Media Lab}
\newcommand{\associateofficename}{}
\newcommand{\roomnumber}{E62-341}
\newcommand{\phonenum}{206.409.7191}
\newcommand{\faxnum}{815.361.7509}
\newcommand{\website}{http://mako.cc/academic/}
\newcommand{\email}{mako@mit.edu}
\newcommand{\person}{Benjamin Mako Hill}
\newcommand{\ID}{\officename}
\newsavebox{\OfficeStuff}
\newsavebox{\MITlogo}
\newsavebox{\contactinfo}
\newsavebox{\phonestuff}


\sbox{\OfficeStuff}
     {\parbox[t]{7.41cm}{\setlength{\baselineskip}{9.2pt}{\boldfont \person}\\\regularfont{\officename}}}

\sbox{\MITlogo}
     {\parbox[t]{2.19cm}
       {\raisebox{-7mm}{\scalebox{.3}{\includegraphics{figures/mitlogo.pdf}}}}}
\sbox{\contactinfo}
     {\parbox[t]{7.37cm}
       {\setlength{\baselineskip}{9.2pt}\vspace{-0.8em}{\boldfont{\color{mitred} Massachusetts Institute of Technology}}\\
	 \regularfont{77 Massachusetts Avenue, \roomnumber\\
	   Cambridge, Massachusetts 02139-4307}}}
\sbox{\phonestuff}
     {\parbox[t]{7.37cm}{\setlength{\baselineskip}{9.2pt}\regularfont{Phone\hspace{2mm}\phonenum\\Fax\hspace{5.5mm}\faxnum\\Email\hspace{2mm} \email\\\website}}}
\newsavebox{\nameandtitle}
\sbox{\nameandtitle}
     {\parbox[t]{3in}{\setlength{\baselineskip}{9.2pt}}}
\newsavebox{\header}
\arrayrulecolor{mitred}
\setlength{\arrayrulewidth}{2pt}
\sbox{\header}
     {\parbox[t]{\textwidth}
       {\begin{tabular*}{\textwidth}{lll@{\extracolsep{\fill}}}
	 \usebox{\OfficeStuff} & \raisebox{.05in}{\usebox{\MITlogo}} & \usebox{\contactinfo} \\
	 &&\\
	 \hline\\
	 \usebox{\nameandtitle}&&\usebox{\phonestuff}
     \end{tabular*}}}

\newsavebox{\footer}

\sbox{\footer}
     {\parbox[t]{\textwidth}{\textcolor{mitred}{\rule{\textwidth}{3mm}}}}
\newsavebox{\envpic}
\sbox{\envpic}
     {\parbox[t]{.75in}
       {\scalebox{.33}{\includegraphics{figures/mitlogo.pdf}}}}
\newsavebox{\envtop}
\sbox{\envtop}
     {\parbox[t]{2.5in}
       {\setlength{\baselineskip}{9.2pt}\boldfont{{\color{mitred} \officename}\\\associateofficename}}}

\newsavebox{\envbottom}
\sbox{\envbottom}
     {\parbox[b]{2.5in}
       {\setlength{\baselineskip}{9.2pt}\boldfont{\color{mitred} Massachusetts Institute of Technology}\\\regularfont{77 Massachusetts Avenue, Building \roomnumber}\\\regularfont{Cambridge, MA 02139-4307}}}

\newsavebox{\envelope}
\sbox{\envelope}
     {\parbox[t]{3.25in}
       {\hspace{.75in}\raisebox{.125in}{\usebox{\envtop}}\\\textcolor{mitred}{\rule{3.25in}{2pt}}\\\\\usebox{\envpic}\usebox{\envbottom}}}

\renewcommand{\returnaddress}{\protect\usebox{\envelope}}

%make sure the header goes on the first page
\renewcommand{\ps@firstpage}
	     {\setlength{\headheight}{70pt}\setlength{\headsep}{25pt}%
	       \renewcommand{\@oddhead}{\usebox{\header}}%
	       \renewcommand{\@evenhead}{}\renewcommand{\@evenfoot}{\usebox{\footer}}\renewcommand{\@oddfoot}{\usebox{\footer}}}
\renewcommand{\ps@plain}{%
\renewcommand{\@evenfoot}{\usebox{\footer}}\renewcommand{\@oddfoot}{\usebox{\footer}}
}

\providecommand{\@evenhead}{}\providecommand{\@oddhead}{}
\providecommand{\@evenfoot}{}\providecommand{\@oddfoot}{}


\pagestyle{headings}
